.. gems documentation master file


Welcome to gems's documentation!
======================================


Overview
--------

The `gems <http://github.com/bprinty/gems>`_ module provides specialized data structures to augment development. It's similar to the `collections <https://docs.python.org/2/library/collections.html>`_ module, but contains different types of objects. For documentation on using these objects, see the `Usage <./usage.html>`_ section of the documentation.


Content:
--------

.. toctree::
   :maxdepth: 2

   installation
   usage
   api


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

